<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation>رشّح:</translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../forms/fontdialog.ui" line="14"/>
        <location filename="../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>اختر خط الطرفية</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>الخط:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>الحجم:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>معاينة</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="94"/>
        <source>Bookmarks</source>
        <translation>العلامات المرجعية</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="211"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>اضغط ”%1“ لترى الطرفية.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="260"/>
        <source>&amp;Next Tab</source>
        <translation>التبويب &amp;التالي</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="263"/>
        <source>&amp;Previous Tab</source>
        <translation>التبويب &amp;السابق</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="272"/>
        <source>Move Tab &amp;Left</source>
        <translation>انقل التبويب &amp;يسارا</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="275"/>
        <source>Move Tab &amp;Right</source>
        <translation>انقل التبويب يمينا</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>&amp;Collapse Subterminal</source>
        <translation>اطوِ الطرفية الفرعية</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="253"/>
        <source>&amp;Clear Active Terminal</source>
        <translation>امسح الطرفية النشطة</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="192"/>
        <source>Keep window open when it loses focus</source>
        <translation>اترك النافذة مفتوحة عندما تفقد التركيز</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="266"/>
        <source>&amp;Previous Tab in History</source>
        <translation>&amp;التبويب السابق في التأريخ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="269"/>
        <source>&amp;Next Tab in History</source>
        <translation>&amp;التبويب التالي في التأريخ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="280"/>
        <source>Tab</source>
        <translation>تبويب</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="281"/>
        <source>Go to</source>
        <translation>انتقل إلى</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="294"/>
        <source>Split &amp;View Top-Bottom</source>
        <translation>تقسيم وعرض من أعلى إلى أسفل</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="297"/>
        <source>Split Vie&amp;w Left-Right</source>
        <translation>تقسيم العرض من اليسار إلى اليمين</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="305"/>
        <source>&amp;Top Subterminal</source>
        <translation>&amp;الطرفية الفرعية العلوية</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>&amp;Bottom Subterminal</source>
        <translation>&amp;الطرفية الفرعية السفلية</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="311"/>
        <source>L&amp;eft Subterminal</source>
        <translation>&amp;الطرفية العلوية اليسرى</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="314"/>
        <source>R&amp;ight Subterminal</source>
        <translation>&amp;الطرفية الفرعية اليمنى</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="321"/>
        <source>Copy &amp;Selection</source>
        <translation>&amp;انسخ التحديد</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="324"/>
        <source>Paste Clip&amp;board</source>
        <translation>&amp;ألصِق الحافظة</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="327"/>
        <source>Paste S&amp;election</source>
        <translation>&amp;ألصِق التحديد</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>Zoom &amp;in</source>
        <translation>&amp;قرّب</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="333"/>
        <source>Zoom &amp;out</source>
        <translation>&amp;بعّد</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="336"/>
        <source>Zoom rese&amp;t</source>
        <translation>&amp;صفّر مستوى التقريب</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="341"/>
        <source>&amp;Find...</source>
        <translation>&amp;ابحث…</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="344"/>
        <source>Handle history...</source>
        <translation>التعامل مع التاريخ ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="352"/>
        <source>&amp;Save Session</source>
        <translation>&amp;احفظ الجلسة</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="358"/>
        <source>&amp;Load Session</source>
        <translation>&amp;حمّل جلسة</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>&amp;Toggle Menu</source>
        <translation>&amp;اعرض/أخفِ القائمة</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="370"/>
        <source>Rename session</source>
        <translation>غيّر اسم الجلسة</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="379"/>
        <source>&amp;New Tab</source>
        <translation>&amp;لسان جديد</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="383"/>
        <source>New Tab From &amp;Preset</source>
        <translation>&amp;لسان جديد من إعداد مسبق</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="384"/>
        <source>1 &amp;Terminal</source>
        <translation>&amp;طرفية واحدة</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="388"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation>&amp;طرفيتان أفقيّتان</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation>&amp;طرفيتان رأسيّتان</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <source>4 Terminal&amp;s</source>
        <translation>&amp;4 طرفيات</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="398"/>
        <source>&amp;Close Tab</source>
        <translation>&amp;أغلِق اللسان</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <source>&amp;New Window</source>
        <translation>&amp;نافذة جديدة</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="406"/>
        <source>&amp;Preferences...</source>
        <translation>&amp;التّفضيلات …</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="410"/>
        <source>&amp;Quit</source>
        <translation>&amp;أنهِ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="416"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;أخفِ حدود النافذة</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>&amp;Show Tab Bar</source>
        <translation>&amp;اعرض شريط الألسنة</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="442"/>
        <source>Fullscreen</source>
        <translation>ملء الشاشة</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="448"/>
        <source>Toggle Bookmarks</source>
        <translation>تبديل الإشارات المرجعية</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="456"/>
        <source>&amp;Bottom</source>
        <translation>&amp;الأسفل</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="457"/>
        <source>&amp;Top</source>
        <translation>&amp;الأعلى</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="458"/>
        <location filename="../mainwindow.cpp" line="494"/>
        <source>&amp;Right</source>
        <translation>&amp;يمين</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="459"/>
        <location filename="../mainwindow.cpp" line="495"/>
        <source>&amp;Left</source>
        <translation>&amp;يسار</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="477"/>
        <source>&amp;Tabs Layout</source>
        <translation>&amp;تخطيط الألسنة</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>&amp;None</source>
        <translation>&amp;بلا</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="511"/>
        <source>S&amp;crollbar Layout</source>
        <translation>&amp;تخطيط شريط التمرير</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="524"/>
        <source>&amp;BlockCursor</source>
        <translation>&amp;مؤشر كتلة</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="525"/>
        <source>&amp;UnderlineCursor</source>
        <translation>&amp;مؤشر تحتي</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>&amp;IBeamCursor</source>
        <translation>&amp;مؤشر عمودي</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="543"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation>&amp;شكل مؤشر لوحة المفاتيح</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="650"/>
        <source>Exit QTerminal</source>
        <translation>الخروج مِن QTerminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="652"/>
        <source>Do not ask again</source>
        <translation>لا تسأل ثانيةً</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="660"/>
        <source>Are you sure you want to exit?</source>
        <translation>أمتأكّد من الخروج؟</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="688"/>
        <source>About</source>
        <translation>عن</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="690"/>
        <source>A lightweight and powerful multiplatform terminal emulator</source>
        <translation>محاكي طرفية خفيف وقوي متعدد المنصات</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="692"/>
        <source>Copyright (C) </source>
        <translation>حقوق النشر (C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="692"/>
        <source>2013-2022</source>
        <translation>2013-2022</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="694"/>
        <source>LXQt Project</source>
        <translation>مشروع LXQt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="696"/>
        <source>Development: </source>
        <translation>تطوير: </translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation>إعدادات الطرفية</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="21"/>
        <source>Appearance</source>
        <translation>المظهر</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="30"/>
        <location filename="../forms/propertiesdialog.ui" line="581"/>
        <source>Behavior</source>
        <translation>السلوك</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="39"/>
        <source>Shortcuts</source>
        <translation>الاختصارات</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="48"/>
        <source>Dropdown</source>
        <translation>منسدل</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="57"/>
        <source>Bookmarks</source>
        <translation>العلامات المرجعية</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="272"/>
        <source>Hide tab bar with only one tab</source>
        <translation>أخفِ شريط الألسنة لو لم يكن هناك إلّا لسان واحد</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="173"/>
        <source>Color scheme</source>
        <translation>مخطّط الألوان</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="199"/>
        <source>Scrollbar position</source>
        <translation>مكان شريط التمرير</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="463"/>
        <source>Start with preset:</source>
        <translation>ابدأ بالإعداد المسبق:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="299"/>
        <source>Show a border around the current terminal</source>
        <translation>اعرض حدًا يُحيط بالطرفية الحالية</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="380"/>
        <source>Terminal transparency</source>
        <translation>شفافية الطرفية</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="354"/>
        <source>Application transparency</source>
        <translation>شفافية التطبيق</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="474"/>
        <source>None (single terminal)</source>
        <translation>لا شيء (طرف واحد)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="479"/>
        <source>2 terminals horizontally</source>
        <translation>2 محطات أفقيا</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="484"/>
        <source>2 terminals vertically</source>
        <translation>محطتان عمودياً</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="489"/>
        <source>4 terminals</source>
        <translation>4 محطات</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="364"/>
        <location filename="../forms/propertiesdialog.ui" line="390"/>
        <source> %</source>
        <translation> ‏٪</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="127"/>
        <source>Font</source>
        <translation>الخط</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="163"/>
        <source>&amp;Change...</source>
        <translation>&amp;غيّر…</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="212"/>
        <source>Tabs position</source>
        <translation>مكان الألسنة</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="186"/>
        <source>Widget style</source>
        <translation>نمط الودجات</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="258"/>
        <source>Show the menu bar</source>
        <translation>اعرض شريط القوائم</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="225"/>
        <source>Cursor shape</source>
        <translation>شكل المؤشر</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="316"/>
        <source>Change window title based on current terminal</source>
        <translation>غيّر عنوان النافذة حسب الطرفية الحالية</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="323"/>
        <source>Change window icon based on current terminal</source>
        <translation>غيّر أيقونة النافذة حسب الطرفية الحالية</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="337"/>
        <source>Enable bi-directional text support</source>
        <translation>فعّل دعم النصوص ثنائية الاتجاه (كالعربية والإنجليزية)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="406"/>
        <source>Background image:</source>
        <translation>صورة الخلفية:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="418"/>
        <source>Select</source>
        <translation>اختر</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="330"/>
        <source>Show terminal size on resize</source>
        <translation>اعرض مقاس الطرفية عند تغيير مقاسها</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="279"/>
        <source>Fixed tab width:</source>
        <translation>عرض لسان ثابت:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="289"/>
        <location filename="../forms/propertiesdialog.ui" line="507"/>
        <source>px</source>
        <translation>بكسل</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="306"/>
        <source>Show close button on each tab</source>
        <translation>اعرض زر الإغلاق في كل لسان</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="497"/>
        <source>Terminal margin</source>
        <translation>هامش الطرفية</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="347"/>
        <source>Use box drawing characters contained in the font</source>
        <translation>استخدم أحرف الرسم المربع المضمنة في الخط</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="248"/>
        <source>Accelerators are activated by Alt and can interfere with the terminal.</source>
        <translation>يُفعّل مفتاح Alt المُسرّعات ويمكن أن يتداخل عملها مع عمل الطرفية.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="251"/>
        <source>No menu bar accelerator</source>
        <translation>بلا مُسرّعات في شريط القوائم</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="830"/>
        <source>Emulation</source>
        <translation>محاكاة</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="614"/>
        <source>Action after paste</source>
        <translation>الإجراء بعد اللصق</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="654"/>
        <source>Confirm multiline paste</source>
        <translation>تأكيد لصق متعدد</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="661"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation>تقليم الأسطر الجديدة اللاحقة في النص الملصق</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="757"/>
        <source>Open new terminals in current working directory</source>
        <translation>افتح محطات جديدة في مجلد العمل الحالي</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="692"/>
        <source>Save Size when closing</source>
        <translation>احفظ المقاس عند الإغلاق</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="685"/>
        <source>Save Position when closing</source>
        <translation>احفظ المكان عند الإغلاق</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="678"/>
        <source>Ask for confirmation when closing</source>
        <translation>اطلب التأكيد عند الإغلاق</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="594"/>
        <source>Unlimited history</source>
        <translation>تأريخ غير محدود</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="587"/>
        <source>History size (in lines)</source>
        <translation>حجم التأريخ (بالأسطر)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="781"/>
        <source>Default $TERM</source>
        <translation>الافتراضي $ TERM</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="704"/>
        <source>Start with this size:</source>
        <translation>ابدأ بهذا المقاس:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="427"/>
        <source>Background mode:</source>
        <translation>وضع الخلفية:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="435"/>
        <source>None</source>
        <translation>لا أحد</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="440"/>
        <source>Stretch</source>
        <translation>مدّ</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="445"/>
        <source>Zoom</source>
        <translation>تكبير</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="450"/>
        <source>Fit</source>
        <translation>ملائم</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="455"/>
        <source>Center</source>
        <translation>مركز</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="344"/>
        <source>Specify whether box drawing characters should be drawn by QTerminal internally or left to underlying font rendering libraries.</source>
        <translation>حدد ما إذا كان يجب رسم أحرف رسم المربعات بواسطة QTerminal داخليًا أو تركها لمكتبات عرض الخطوط الأساسية.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="238"/>
        <source>Toggles usage of bold font face for rendering intense colors</source>
        <translation>يبدل استخدام وجه الخط الغامق لتقديم ألوان مكثفة</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="241"/>
        <source>Use bold font face for intense colors</source>
        <translation>إستعمل خط عريض للأ لوان الداكنة</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="265"/>
        <source>&amp;Hide Window Borders</source>
        <translation>أ&amp;خفِ حدود النافذة</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="839"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;If you are not sure, use the &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;أي سلوك لمحاكاته. لاحظ أن هذا لا يجب أن يتطابق مع نظام التشغيل الخاص بك.&lt;/p&gt;&lt;p&gt;إذا لم تكن متأكدًا ، فاستخدم &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="817"/>
        <source>This command will be run with an argument containing the file name of a tempfile containing the scrollback history</source>
        <translation>سيتم تشغيل هذا الأمر باستخدام وسيطة تحتوي على اسم ملف الملف المؤقت الذي يحتوي على محفوظات التمرير</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="820"/>
        <source>Handle history command</source>
        <translation>التعامل مع أمر التاريخ</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="711"/>
        <location filename="../forms/propertiesdialog.ui" line="725"/>
        <source> px</source>
        <translation> بكسل</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="732"/>
        <source>Get current size</source>
        <translation>احصل على الحجم الحالي</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="767"/>
        <source>Open new tab to the right of the active tab</source>
        <translation>افتح لسان جديد على يمين اللسان النشط</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="764"/>
        <source>If unchecked the new tab will be opened as the rightmost tab</source>
        <translation>إذا لم يتم تحديده ، فسيتم فتح اللسان الجديد باعتباره لسان موجودة في أقصى اليمين</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="668"/>
        <source>Close tab on middle-click</source>
        <translation>إغلاق علامة التبويب في النقر الأوسط</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="647"/>
        <source>Forcefully disable bracketed paste mode</source>
        <translation>قم بتعطيل وضع اللصق بين قوسين بقوة</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="627"/>
        <source>Word selection characters</source>
        <translation>أحرف اختيار الكلمات</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="634"/>
        <source>When selecting text by word, consider these characters as part of words in addition to alphanumeric characters</source>
        <translation>عند تحديد نص بكلمة، يجب مراعاة هذه الأحرف كجزء من الكلمات بالإضافة إلى الأحرف الأبجدية الرقمية</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="637"/>
        <source>:@-./_~</source>
        <translation>:@-./_~</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="644"/>
        <source>Bracketed paste mode is useful for pasting multiline strings.</source>
        <translation>وضع اللصق بين قوسين مفيد للصق سلاسل متعددة الأسطر.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="774"/>
        <source>Audible bell</source>
        <translation>جرس مسموع</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="863"/>
        <source>To edit a Shortcut:
1. Double-click its Key
2. Press the desired combination and release it
3. Click on a Shortcut or press Enter

To remove/disable a Shortcut, at point 2 press only a modifier (like Shift)</source>
        <translation>لتحرير اختصار:
1. انقر نقرًا مزدوجًا فوق مفتاحه
2. اضغط على المجموعة المرغوبة ثم حررها
3. انقر فوق اختصار أو اضغط على Enter

لإزالة / تعطيل اختصار ، عند النقطة 2 ، اضغط على معدِّل فقط (مثل Shift)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="893"/>
        <source>Shortcut</source>
        <translation>الاختصار</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="898"/>
        <source>Key</source>
        <translation>المفتاح</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="910"/>
        <source>Show on start</source>
        <translation>عرضه عند البدء</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="917"/>
        <source>A lock button is shown on horizontal tab bar</source>
        <translation>يظهر زر القفل على شريط الألسنة الأفقي</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="920"/>
        <source>Keep window open when it loses focus</source>
        <translation>اترك النافذة مفتوحة عندما تفقد التركيز</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="927"/>
        <source>Size</source>
        <translation>المقاس</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="938"/>
        <source>Height</source>
        <translation>الارتفاع</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="948"/>
        <location filename="../forms/propertiesdialog.ui" line="965"/>
        <source>%</source>
        <translation>٪</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="955"/>
        <source>Width</source>
        <translation>العرض</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="979"/>
        <source>Shortcut:</source>
        <translation>الاختصار:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="988"/>
        <source>Note: On Wayland, the shortcut has to be added in the compositor settings for &apos;qterminal -d&apos;.</source>
        <translation>ملاحظة: في Wayland، يجب إضافة الاختصار في إعدادات المنضد لـ &apos;qterminal -d&apos;.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1056"/>
        <source>Edit bookmark file contents</source>
        <translation>تحرير محتويات ملف الإشارات المرجعية</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1015"/>
        <source>Enable bookmarks</source>
        <translation>فعّل العلامات</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1024"/>
        <source>Bookmark file</source>
        <translation>ملف العلامات</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1037"/>
        <source>Find...</source>
        <translation>بحث...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1046"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation>يمكنك تحديد مكان ملف العلامات الخاص بك. بهذا يمكنك مشاركته بسهولة على تثبيتات مثل OwnCloud أو Dropbox.</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="164"/>
        <source>No scrollbar</source>
        <translation>بلا شريط تمرير</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="164"/>
        <location filename="../propertiesdialog.cpp" line="170"/>
        <source>Left</source>
        <translation>يسار</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="164"/>
        <location filename="../propertiesdialog.cpp" line="170"/>
        <source>Right</source>
        <translation>يمين</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="170"/>
        <source>Top</source>
        <translation>أعلى</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="170"/>
        <source>Bottom</source>
        <translation>أسفل</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="183"/>
        <source>BlockCursor</source>
        <translation>كتلة المؤشر</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="183"/>
        <source>UnderlineCursor</source>
        <translation>تسطير المؤشر</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="183"/>
        <source>IBeamCursor</source>
        <translation>مؤشر عمودي</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="201"/>
        <source>No move</source>
        <translation>لا حركة</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="201"/>
        <source>Scrolling to top</source>
        <translation>التمرير للأعلى</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="201"/>
        <source>Scrolling to bottom</source>
        <translation>التمرير للأسفل</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="276"/>
        <source>Examples</source>
        <translation>أمثلة</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="430"/>
        <source>Images (*.bmp *.jpg *.png *.svg *.xpm)</source>
        <translation>الصور (* .bmp * .jpg * .png * .svg * .xpm)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="532"/>
        <source>Open bookmarks file</source>
        <translation>افتح ملف الإشارات المرجعية</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="534"/>
        <source>XML files (*.xml)</source>
        <translation>ملفات XML (* .xml)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="535"/>
        <source>All files (*)</source>
        <translation>كل الملفات (*)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="634"/>
        <location filename="../propertiesdialog.cpp" line="638"/>
        <source>Question</source>
        <translation>سؤال</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="634"/>
        <source>Do you want to overwrite this bookmarks file?</source>
        <translation>هل تريد الكتابة فوق ملف الإشارات المرجعية هذا؟</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="638"/>
        <source>The name of bookmarks file does not end with &apos;.xml&apos;.
Are you sure that you want to overwrite it?</source>
        <translation>لا ينتهي اسم ملف الإشارات المرجعية بـ &quot;.xml&quot;.
هل أنت متأكد أنك تريد الكتابة فوقه؟</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="646"/>
        <source>Warning</source>
        <translation>تحذير</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="646"/>
        <source>Cannot write bookmarks to this file:</source>
        <translation>لا يمكن كتابة إشارات مرجعية لهذا الملف:</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="211"/>
        <location filename="../propertiesdialog.cpp" line="324"/>
        <source>System Default</source>
        <translation>مبدئيات النظام</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="429"/>
        <source>Choose a background image</source>
        <translation>اختر صورة الخلفية</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bookmarkswidget.cpp" line="114"/>
        <source>Synchronized Bookmarks</source>
        <translation>الإشارات المرجعية المتزامنة</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../tabwidget.cpp" line="81"/>
        <location filename="../tabwidget.cpp" line="235"/>
        <source>Shell No. %1</source>
        <translation>غلاف رقم %1</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="203"/>
        <source>Tab name</source>
        <translation>اسم التبويب</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="204"/>
        <source>New tab name:</source>
        <translation>اسم التبويب الجديد:</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="224"/>
        <source>Select new tab title color</source>
        <translation>اختر لون عنوان التبويب الجديد</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="253"/>
        <source>Close session</source>
        <translation>أغلِق الجلسة</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="255"/>
        <source>Change title color</source>
        <translation>غيّر لون العنوان</translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../termwidgetholder.cpp" line="77"/>
        <source>Load Session</source>
        <translation>حمّل جلسة</translation>
    </message>
    <message>
        <location filename="../termwidgetholder.cpp" line="78"/>
        <source>List of saved sessions:</source>
        <translation>قائمة بالجلسات المحفوظة:</translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation>النافذة الرئيسية</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="59"/>
        <source>&amp;File</source>
        <translation>&amp;ملف</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="67"/>
        <source>&amp;Actions</source>
        <translation>إ&amp;جراءات</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>م&amp;ساعدة</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="79"/>
        <source>&amp;View</source>
        <translation>من&amp;ظور</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="84"/>
        <source>&amp;Edit</source>
        <translation>ت&amp;حرير</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="100"/>
        <source>&amp;About...</source>
        <translation>&amp;عن…</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="105"/>
        <source>About &amp;Qt...</source>
        <translation>&amp;عن Qt...</translation>
    </message>
</context>
</TS>
